@@ -2,7 +2,7 @@
 /*
  This file is part of SLRN.
 
- Copyright (c) 1994, 1999, 2007-2008 John E. Davis <jed@jedsoft.org>
+ Copyright (c) 1994, 1999, 2007-2016 John E. Davis <jed@jedsoft.org>
  Copyright (c) 2001-2006 Thomas Schultz <tststs@gmx.de>
 
  This program is free software; you can redistribute it and/or modify it
@@ -17,7 +17,7 @@
 
  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
- 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #include "config.h"
 #include "slrnfeat.h"
@@ -28,7 +28,6 @@
 #include <string.h>
 #include <time.h>
 
-
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif
@@ -51,7 +50,7 @@
 #include "post.h"
 /* #include "clientlib.h" */
 #include "startup.h"
-#include "hash.h" 
+#include "hash.h"
 #include "score.h"
 #include "menu.h"
 #include "xover.h"
@@ -62,6 +61,7 @@
 static int Art_Hide_Quote_Level = 1;
 int Slrn_Wrap_Mode = 3;
 int Slrn_Wrap_Method = 2;
+int Slrn_Wrap_Width = -1;
 
 static char *Super_Cite_Regexp = "^[^A-Za-z0-9]*\"\\([-_a-zA-Z/]+\\)\" == .+";
 
@@ -71,7 +71,7 @@ static void hide_article_lines (Slrn_Article_Type *a, unsigned int mask) /*{{{*/
 
    if (a == NULL)
      return;
-   
+
    a->needs_sync = 1;
    l = a->lines;
 
@@ -107,7 +107,7 @@ static void unhide_article_lines (Slrn_Article_Type *a, unsigned int mask) /*{{{
 
 /*}}}*/
 
-/* The function that set the needs_sync flag article line number start with _ 
+/* The function that set the needs_sync flag article line number start with _
  */
 
 int _slrn_art_unhide_quotes (Slrn_Article_Type *a) /*{{{*/
@@ -134,7 +134,7 @@ static unsigned char *is_matching_line (unsigned char *b, SLRegexp_Type **r) /*{
 
 	re = *r++;
 #if SLANG_VERSION < 20000
-	if ((re->min_length > len) 
+	if ((re->min_length > len)
 	    || (b != SLang_regexp_match (b, len, re)))
 	  continue;
 	match_len = re->end_matches[0];
@@ -153,17 +153,17 @@ static unsigned char *is_matching_line (unsigned char *b, SLRegexp_Type **r) /*{
 int _slrn_art_hide_quotes (Slrn_Article_Type *a, int reset) /*{{{*/
 {
    Slrn_Article_Line_Type *l, *last;
-   
+
    if (a == NULL)
      return -1;
 
    _slrn_art_unhide_quotes (a);
-   
+
    a->needs_sync = 1;
 
    if (!reset)
      Art_Hide_Quote_Level = Slrn_Quotes_Hidden_Mode;
-   
+
    l = a->lines;
    last = NULL;
 
@@ -209,23 +209,22 @@ int _slrn_art_hide_quotes (Slrn_Article_Type *a, int reset) /*{{{*/
 
 /*}}}*/
 
-
 #if SLRN_HAS_SPOILERS
 void slrn_art_mark_spoilers (Slrn_Article_Type *a) /*{{{*/
 {
    Slrn_Article_Line_Type *l;
-   
+
    if ((Slrn_Spoiler_Char == 0) || (a == NULL))
      return;
 
    l = a->lines;
-   
+
    while ((l != NULL) && (l->flags & HEADER_LINE))
      l = l->next; /* skip header */
-   
+
    while ((l != NULL) && (NULL == slrn_strbyte (l->buf, 12)))
      l = l->next; /* skip to first formfeed */
-   
+
    while (l != NULL)
      {
 	l->flags |= SPOILER_LINE;
@@ -266,7 +265,7 @@ static int try_supercite (Slrn_Article_Line_Type *l) /*{{{*/
        && (NULL == (re = SLregexp_compile (Super_Cite_Regexp, 0))))
      return -1;
 #endif
-   
+
    /* skip header --- I should look for Xnewsreader: gnus */
    while ((l != NULL) && (*l->buf != 0)) l = l->next;
 
@@ -290,9 +289,9 @@ static int try_supercite (Slrn_Article_Line_Type *l) /*{{{*/
 	     l = l->next;
 	     count--;
 	  }
-	
+
 	if ((l == NULL) || (count == 0)) return ret;
-	
+
 	/* Now find out what is used for citing. */
 	if (-1 == SLregexp_nth_match (re, 1, &ofs, &len))
 	  return ret;
@@ -302,16 +301,16 @@ static int try_supercite (Slrn_Article_Line_Type *l) /*{{{*/
 
 	ret = 0;
 	strncpy (name, (char *) b, len); name[len] = 0;
-	
+
 	while (l != NULL)
 	  {
 	     unsigned char ch;
-	     
+
 	     b = (unsigned char *) l->buf;
 	     last = l;
 	     l = l->next;
 	     if (last->flags & QUOTE_LINE) continue;
-	     
+
 	     b = (unsigned char *) slrn_skip_whitespace ((char *) b);
 
 	     if (!strncmp ((char *) b, name, len)
@@ -319,7 +318,7 @@ static int try_supercite (Slrn_Article_Line_Type *l) /*{{{*/
 		     || (ch > 'z')))
 	       {
 		  last->flags |= QUOTE_LINE;
-		  
+
 		  while (l != NULL)
 		    {
 		       b = (unsigned char *) slrn_skip_whitespace (l->buf);
@@ -343,7 +342,7 @@ void slrn_art_mark_quotes (Slrn_Article_Type *a) /*{{{*/
 {
    Slrn_Article_Line_Type *l;
    unsigned char *b;
-   
+
    if (a == NULL)
      return;
 
@@ -351,9 +350,9 @@ void slrn_art_mark_quotes (Slrn_Article_Type *a) /*{{{*/
      {
 	/* return; */
      }
-   
+
    if (Slrn_Ignore_Quote_Regexp[0] == NULL) return;
-   
+
    /* skip header */
    l = a->lines;
    while ((l != NULL) && (l->flags == HEADER_LINE))
@@ -385,25 +384,25 @@ void slrn_art_mark_quotes (Slrn_Article_Type *a) /*{{{*/
 void slrn_art_mark_signature (Slrn_Article_Type *a) /*{{{*/
 {
    Slrn_Article_Line_Type *l;
-   
+
    if (a == NULL)
      return;
-   
+
    l = a->lines;
    if (l == NULL) return;
    /* go to end of article */
    while (l->next != NULL) l = l->next;
 
    /* skip back until a line matches the signature RegExp */
-   
+
    while ((l != NULL) && (0 == (l->flags & HEADER_LINE))
 	  && ((l->flags & VERBATIM_LINE) ||
 	      (NULL == is_matching_line ((unsigned char *) l->buf,
 					 Slrn_Strip_Sig_Regexp))))
      l = l->prev;
-   
+
    if ((l == NULL) || (l->flags & HEADER_LINE)) return;
-   
+
    while (l != NULL)
      {
         l->flags |= SIGNATURE_LINE;
@@ -434,7 +433,7 @@ static Slrn_Article_Line_Type *unwrap_line (Slrn_Article_Type *a, /*{{{*/
 
    ll = l->prev;
    b = ll->buf;
-   do 
+   do
      {
 	b += strlen (b);
 	/* skip the space at beginning of the wrapped line: */
@@ -446,7 +445,7 @@ static Slrn_Article_Line_Type *unwrap_line (Slrn_Article_Type *a, /*{{{*/
 	l = next;
      }
    while ((l != NULL) && (l->flags & WRAPPED_LINE));
-	     
+
    ll->next = l;
    if (l != NULL) l->prev = ll;
    return l;
@@ -459,7 +458,7 @@ static Slrn_Article_Line_Type *unwrap_line (Slrn_Article_Type *a, /*{{{*/
 int _slrn_art_unwrap_article (Slrn_Article_Type *a) /*{{{*/
 {
    Slrn_Article_Line_Type *l;
-   
+
    if (a == NULL)
      return -1;
 
@@ -481,10 +480,13 @@ int _slrn_art_unwrap_article (Slrn_Article_Type *a) /*{{{*/
 
 int _slrn_art_wrap_article (Slrn_Article_Type *a) /*{{{*/
 {
-   unsigned int len;
    unsigned char *buf, ch;
    Slrn_Article_Line_Type *l;
    unsigned int wrap_mode = Slrn_Wrap_Mode;
+   int wrap_width = Slrn_Wrap_Width;
+
+   if ((wrap_width < 5) || (wrap_width > SLtt_Screen_Cols))
+     wrap_width = SLtt_Screen_Cols;
 
    if (a == NULL)
      return -1;
@@ -505,7 +507,7 @@ int _slrn_art_wrap_article (Slrn_Article_Type *a) /*{{{*/
      {
 	unsigned char header_char_delimiter = 0;
 
-	if (l->flags & HEADER_LINE) 
+	if (l->flags & HEADER_LINE)
 	  {
 	     if ((wrap_mode & 1) == 0)
 	       {
@@ -527,13 +529,12 @@ int _slrn_art_wrap_article (Slrn_Article_Type *a) /*{{{*/
 	       }
 	  }
 
-	len = 0;
 	buf = (unsigned char *) l->buf;
 	ch = *buf;
 	while (ch != 0)
 	  {
 	     unsigned int bytes = SLsmg_strbytes (buf, buf+strlen((char *)buf),
-						  (unsigned int) SLtt_Screen_Cols);
+						  (unsigned int) wrap_width);
 	     buf += bytes;
 	     while ((*buf == ' ') || (*buf == '\t'))
 	       buf++;
@@ -542,20 +543,20 @@ int _slrn_art_wrap_article (Slrn_Article_Type *a) /*{{{*/
 		  Slrn_Article_Line_Type *new_l;
 		  unsigned char *buf0, *lbuf;
 
-		  /* Try to break the line on a word boundary.  
+		  /* Try to break the line on a word boundary.
 		   * For now, I will only break on space characters.
 		   */
 		  buf0 = buf;
 		  lbuf = (unsigned char *) l->buf;
 
 		  lbuf += 1;	       /* avoid space at beg of line */
-		  
+
 		  if (Slrn_Wrap_Method == 0 || Slrn_Wrap_Method == 2)
 		    {
 		       while (buf0 > lbuf)
 			 {
 			    if ((*buf0 == ' ') || (*buf0 == '\t')
-				|| (header_char_delimiter 
+				|| (header_char_delimiter
 				    && (*buf0 == header_char_delimiter)))
 			      {
 				 buf = buf0;
@@ -563,19 +564,19 @@ int _slrn_art_wrap_article (Slrn_Article_Type *a) /*{{{*/
 			      }
 			    buf0--;
 			 }
-		       
+
 		       if (buf0 == lbuf)
 			 {
 			    if (Slrn_Wrap_Method == 0)
 			      {
 		       /* Could not find a place to break the line.  Ok, so
-			* we will not break this.  Perhaps it is a URL.  
+			* we will not break this.  Perhaps it is a URL.
 			* If not, it is a long word and who cares about it.
 			*/
 				 while (((ch = *buf) != 0)
 					&& (ch != ' ') && (ch != '\t'))
 				   buf++;
-				 
+
 				 if (ch == 0)
 				   continue;
 			      }
@@ -585,7 +586,7 @@ int _slrn_art_wrap_article (Slrn_Article_Type *a) /*{{{*/
 			    }
 			 }
 		    }
-		  
+
 		  /* Start wrapped lines with a space.  To do this, I will
 		   * _temporally_ modify the previous character for the purpose
 		   * of creating the new space.
@@ -593,11 +594,11 @@ int _slrn_art_wrap_article (Slrn_Article_Type *a) /*{{{*/
 		  buf--;
 		  ch = *buf;
 		  *buf = ' ';
-		  
+
 		  new_l = (Slrn_Article_Line_Type *) slrn_malloc (sizeof (Slrn_Article_Line_Type), 1, 1);
 		  if (new_l == NULL)
 		    return -1;
-		  
+
 		  if (NULL == (new_l->buf = slrn_strmalloc ((char *)buf, 1)))
 		    {
 		       slrn_free ((char *) new_l);
@@ -606,7 +607,7 @@ int _slrn_art_wrap_article (Slrn_Article_Type *a) /*{{{*/
 
 		  *buf++ = ch;
 		  *buf = 0;
-		  
+
 		  new_l->next = l->next;
 		  new_l->prev = l;
 		  l->next = new_l;
@@ -619,13 +620,12 @@ int _slrn_art_wrap_article (Slrn_Article_Type *a) /*{{{*/
 
 		  l = new_l;
 		  buf = (unsigned char *) new_l->buf;
-		  len = 0;
 		  a->is_wrapped = 1;
 	       }
 #if SLANG_VERSION < 20000
 	     else buf++;
 #endif
-	     
+
 	     ch = *buf;
 	  }
 	l = l->next;
@@ -635,7 +635,6 @@ int _slrn_art_wrap_article (Slrn_Article_Type *a) /*{{{*/
 
 /*}}}*/
 
-
 static int is_blank_line (unsigned char *b) /*{{{*/
 {
    b = (unsigned char *) slrn_skip_whitespace ((char *) b);
@@ -664,16 +663,16 @@ void _slrn_art_skip_quoted_text (Slrn_Article_Type *a) /*{{{*/
 	  }
 	l = l->next;
      }
-   
+
    /* Now we are either at the end of the buffer or on a quote line. Skip
     * past other quote lines.
     */
-   
+
    if (l == NULL)
      return;
-   
+
    l = l->next;
-   
+
    while (l != NULL)
      {
 	if (l->flags & HIDDEN_LINE)
@@ -723,13 +722,13 @@ int _slrn_art_skip_digest_forward (Slrn_Article_Type *a) /*{{{*/
 	  {
 	     char ch;
 	     char *buf;
-	     
+
 	     if ((l->flags & HIDDEN_LINE) || (l->flags & HEADER_LINE))
 	       {
 		  l = l->next;
 		  continue;
 	       }
-	     
+
 	     buf = l->buf;
 	     if (num_passes == 0)
 	       {
@@ -749,7 +748,7 @@ int _slrn_art_skip_digest_forward (Slrn_Article_Type *a) /*{{{*/
 		       continue;
 		    }
 	       }
-	     
+
 	     a->cline = l;
 	     a->needs_sync = 1;
 	     return 0;
@@ -768,7 +767,7 @@ char *slrn_art_extract_header (char *hdr, unsigned int len) /*{{{*/
 
    if (a == NULL)
      return NULL;
-   
+
    l = a->lines;
 
    while ((l != NULL)
@@ -787,7 +786,7 @@ char *slrn_art_extract_header (char *hdr, unsigned int len) /*{{{*/
 
 	     /* Return the data after the colon */
 	     result = slrn_strbyte (l->buf, ':');
-	     if (result == NULL) 
+	     if (result == NULL)
 	       result = l->buf + len;
 	     else result += 1;
 
@@ -830,14 +829,13 @@ static void free_visible_header_list (void) /*{{{*/
 
 /*}}}*/
 
-
 int slrn_set_visible_headers (char *headers) /*{{{*/
 {
    char buf[256];
    unsigned int nth;
 
    free_visible_header_list ();
-   
+
    Slrn_Visible_Headers_String = SLang_create_slstring (headers);
    if (Slrn_Visible_Headers_String == NULL)
      return -1;
@@ -846,7 +844,7 @@ int slrn_set_visible_headers (char *headers) /*{{{*/
    while (-1 != SLextract_list_element (headers, nth, ',', buf, sizeof(buf)))
      {
 	Visible_Header_Type *next;
-	
+
 	next = (Visible_Header_Type *) SLmalloc (sizeof (Visible_Header_Type));
 	if (next == NULL)
 	  return -1;
@@ -859,7 +857,7 @@ int slrn_set_visible_headers (char *headers) /*{{{*/
 	next->len = strlen (buf);
 	next->next = Visible_Headers;
 	Visible_Headers = next;
-	
+
 	nth++;
      }
    if ((Slrn_Current_Article != NULL) &&
@@ -874,21 +872,21 @@ void _slrn_art_hide_headers (Slrn_Article_Type *a) /*{{{*/
 {
    Slrn_Article_Line_Type *l;
    char ch;
-   
+
    if (a == NULL)
      return;
 
    _slrn_art_unhide_headers (a);
 
    a->needs_sync = 1;
-   
+
    l = a->lines;
 
    while ((l != NULL) && (l->flags & HEADER_LINE))
      {
 	int hide_header;
 	Visible_Header_Type *v;
-	
+
 	ch = l->buf[0];
 	ch |= 0x20;
 
@@ -899,7 +897,7 @@ void _slrn_art_hide_headers (Slrn_Article_Type *a) /*{{{*/
 	  {
 	     int hide = (v->header[0] == '!') ? 1 : 0;
 	     char chv = (0x20 | v->header[hide]);
-	     
+
 	     if ((chv == ch)
 		 && (0 == slrn_case_strncmp (l->buf,
 					     v->header + hide,
@@ -908,7 +906,7 @@ void _slrn_art_hide_headers (Slrn_Article_Type *a) /*{{{*/
 		  hide_header = hide;
 		  break;
 	       }
-	     
+
 	     v = v->next;
 	  }
 
@@ -916,7 +914,7 @@ void _slrn_art_hide_headers (Slrn_Article_Type *a) /*{{{*/
 	  {
 	     if (hide_header)
 	       l->flags |= HIDDEN_LINE;
-	     
+
 	     l = l->next;
 	  }
 	while ((l != NULL) && ((*l->buf == ' ') || (*l->buf == '\t')));
@@ -941,10 +939,10 @@ int _slrn_art_unfold_header_lines (Slrn_Article_Type *a) /*{{{*/
 {
    Slrn_Article_Line_Type *l;
    char ch;
-   
+
    if (a == NULL)
      return -1;
-   
+
    l = a->lines->next;
    a->is_modified = 1;
    a->needs_sync = 1;
@@ -957,20 +955,20 @@ int _slrn_art_unfold_header_lines (Slrn_Article_Type *a) /*{{{*/
 	     unsigned int len0, len1;
 	     Slrn_Article_Line_Type *prev;
 	     char *new_buf;
-	     
+
 	     l->buf[0] = ' ';
-	     
+
 	     prev = l->prev;
-	     
+
 	     len0 = strlen (prev->buf);
 	     len1 = len0 + strlen (l->buf) + 1;
-	     
+
 	     new_buf = slrn_realloc (prev->buf, len1, 1);
 	     if (new_buf == NULL)
 	       return -1;
 
 	     prev->buf = new_buf;
-	     
+
 	     strcpy (new_buf + len0, l->buf); /* safe */
 	     prev->next = l->next;
 	     if (l->next != NULL) l->next->prev = prev;
@@ -978,7 +976,7 @@ int _slrn_art_unfold_header_lines (Slrn_Article_Type *a) /*{{{*/
 	     slrn_free ((char *) l);
 	     l = prev;
 	  }
-	
+
 	l = l->next;
      }
    return 0;
@@ -989,7 +987,7 @@ int _slrn_art_unfold_header_lines (Slrn_Article_Type *a) /*{{{*/
 void slrn_mark_header_lines (Slrn_Article_Type *a) /*{{{*/
 {
    Slrn_Article_Line_Type *l;
-   
+
    if (a == NULL)
      return;
    l = a->lines;
@@ -1026,12 +1024,12 @@ void _slrn_art_unhide_signature (Slrn_Article_Type *a) /*{{{*/
 /*}}}*/
 
 void slrn_art_mark_pgp_signature (Slrn_Article_Type *a) /*{{{*/
-{	
+{
    Slrn_Article_Line_Type *l;
 
    if (a == NULL)
      return;
-   
+
    l = a->lines;
    while (l != NULL)
      {
@@ -1043,14 +1041,14 @@ void slrn_art_mark_pgp_signature (Slrn_Article_Type *a) /*{{{*/
 	  {
 	     l->flags |= PGP_SIGNATURE_LINE;
 	     l->flags &= ~QUOTE_LINE;
-	     
+
 	     if ((NULL != (l = l->next)) &&
 		 !strncmp (l->buf, "Hash: ", 6))
 	       {
 		  /* catch the `Hash: ... ' line */
 		  l->flags |= PGP_SIGNATURE_LINE;
 		  l->flags &= ~QUOTE_LINE;
-		  
+
 		  l = l->next;
 	       }
 	     if ((NULL != l) &&
@@ -1059,10 +1057,10 @@ void slrn_art_mark_pgp_signature (Slrn_Article_Type *a) /*{{{*/
 		  /* the optional "NotDashEscaped: ..." line */
 		  l->flags |= PGP_SIGNATURE_LINE;
 		  l->flags &= ~QUOTE_LINE;
-		  
-		  l = l->next;		  
+
+		  l = l->next;
 	       }
-	     
+
 	     continue;
 	  }
 
@@ -1074,8 +1072,8 @@ void slrn_art_mark_pgp_signature (Slrn_Article_Type *a) /*{{{*/
 	  }
 	l0 = l;
 	l = l->next;
-	
-	count = 20;
+
+	count = 256;		       /* arbitrary */
 	while ((l != NULL) && count)
 	  {
 	     if ((l->buf[0] != '-')
@@ -1134,7 +1132,7 @@ void slrn_art_mark_verbatim (Slrn_Article_Type *a)
 
    if (a == NULL)
      return;
-   
+
    von = "#v+";
    voff = "#v-";
 
@@ -1173,7 +1171,6 @@ void slrn_art_mark_verbatim (Slrn_Article_Type *a)
      }
 }
 
-
 void _slrn_art_unhide_verbatim (Slrn_Article_Type *a) /*{{{*/
 {
    if (a == NULL)
