@@ -2,7 +2,7 @@
 /*
  This file is part of SLRN.
 
- Copyright (c) 1994, 1999, 2007-2008 John E. Davis <jed@jedsoft.org>
+ Copyright (c) 1994, 1999, 2007-2016 John E. Davis <jed@jedsoft.org>
  Copyright (c) 2001-2006 Thomas Schultz <tststs@gmx.de>
 
  This program is free software; you can redistribute it and/or modify it
@@ -17,7 +17,7 @@
 
  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
- 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #include "config.h"
 #include "slrnfeat.h"
@@ -103,7 +103,7 @@ static int uudecode_fclose (FILE *fp, FILE *pipe_fp) /*{{{*/
 {
    if ((fp == pipe_fp) || (fp == NULL))
      return 0;
-   
+
 #ifdef STANDALONE
    if (0 == fclose (fp)) return 0;
    slrn_error (_("Error closing file.  File system full?"));
@@ -120,7 +120,7 @@ static int uudecode_fclose (FILE *fp, FILE *pipe_fp) /*{{{*/
 static int unpack_as_shell_archive (FILE *fp, char *buf, int size) /*{{{*/
 {
    FILE *pp;
-   
+
    size--;
    pp = SLRN_POPEN ("/bin/sh", "w");
    if (pp == NULL)
@@ -128,14 +128,14 @@ static int unpack_as_shell_archive (FILE *fp, char *buf, int size) /*{{{*/
 	slrn_error (_("Unable to open /bin/sh\n"));
 	return -1;
      }
-   
+
    while (fgets (buf, size, fp) != NULL)
      {
 	fputs (buf, pp);
 	if (!strcmp (buf, "exit 0\n"))
 	  break;
      }
-   
+
    if (-1 == SLRN_PCLOSE (pp))
      {
 	slrn_error (_("Error encountered while processing shell archive.\n"));
@@ -146,15 +146,27 @@ static int unpack_as_shell_archive (FILE *fp, char *buf, int size) /*{{{*/
 
 /*}}}*/
 #endif
+
+static int file_exists (char *file)
+{
+   struct stat st;
+
+   if (-1 == stat (file, &st))
+     return 0;
+
+   return 1;
+}
+
 /* Note: this function modifies name */
 static FILE *open_output_file (char *name, char *type, int mode, FILE *use_this) /*{{{*/
 {
    FILE *fp;
    char *p;
+   char *file = NULL;
 
    if (use_this != NULL)
      return use_this;
-   
+
    p = name;
    while (*p != 0)
      {
@@ -163,32 +175,61 @@ static FILE *open_output_file (char *name, char *type, int mode, FILE *use_this)
 	p++;
      }
 
+   if (1 == file_exists (name))
+     {
+	unsigned int i;
+	unsigned int len = strlen (name);
+
+	len += 1 + 4 + 1;
+	if (NULL == (file = slrn_malloc (len, 0, 1)))
+	  return NULL;
+
+	for (i = 1; i <= 9999; i++)
+	  {
+	     (void) slrn_snprintf (file, len, "%s-%d", name, i);
+	     if (0 == file_exists (file))
+	       {
+		  name = file;
+		  break;
+	       }
+	  }
+
+	if (name != file)
+	  {
+	     slrn_free (file);
+	     slrn_error(_("Unable to create %s\n"), name);
+	     return NULL;
+	  }
+     }
+
    fp = fopen (name, "wb");
-	
+
    if (fp == NULL)
      {
 	slrn_error(_("Unable to create %s\n"), name);
+	if (file != NULL) slrn_free (file);
 	return NULL;
      }
-   
+
    slrn_message_now (_("creating %s (%s)\n"), name, type);
-   
-   if (mode != -1) 
+
+   if (mode != -1)
      chmod (name, mode);
-   
+
+   if (file != NULL) slrn_free (file);
    return fp;
 }
 
 /*}}}*/
 
 static unsigned char Base64_Table [256];
-   
+
 static void initialize_base64 (void) /*{{{*/
 {
    int i;
-   
+
    for (i = 0; i < 256; i++) Base64_Table[i] = 0xFF;
-   
+
    for (i = 'A'; i <= 'Z'; i++) Base64_Table[i] = (unsigned char) (i - 'A');
    for (i = 'a'; i <= 'z'; i++) Base64_Table[i] = 26 + (unsigned char) (i - 'a');
    for (i = '0'; i <= '9'; i++) Base64_Table[i] = 52 + (unsigned char) (i - '0');
@@ -208,7 +249,7 @@ static int base64_decode_line (char *line, FILE *fp) /*{{{*/
    unsigned char ch1;
    unsigned char bytes[3];
    unsigned char *p;
-   
+
    p = (unsigned char *) line;
    /* Perform simple syntax check.  The loop following this one
     * assumes this.
@@ -217,11 +258,11 @@ static int base64_decode_line (char *line, FILE *fp) /*{{{*/
      {
 	if (Base64_Table[ch] == 0xFF)
 	  return -1;
-	
+
 	ch = *p++;
 	if (Base64_Table[ch] == 0xFF)
 	  return -1;
-	
+
 	ch = *p++;
 	if ((Base64_Table[ch] == 0xFF) && (ch != '='))
 	  {
@@ -239,13 +280,13 @@ static int base64_decode_line (char *line, FILE *fp) /*{{{*/
      {
 	ch1 = Base64_Table[ch];
 	bytes[0] = ch1 << 2;
-	
+
 	ch = *line++;
 	ch1 = Base64_Table[ch];
-	
+
 	bytes[0] |= ch1 >> 4;
 	bytes[1] = ch1 << 4;
-	
+
 	ch = *line++;
 	ch1 = Base64_Table[ch];
 	if (ch1 == 0xFF)
@@ -253,10 +294,10 @@ static int base64_decode_line (char *line, FILE *fp) /*{{{*/
 	     fwrite (bytes, 1, 1, fp);
 	     return 1;
 	  }
-	
+
 	bytes[1] |= ch1 >> 2;
 	bytes[2] = ch1 << 6;
-	
+
 	ch = *line++;
 	ch1 = Base64_Table[ch];
 	if (ch1 == 0xFF)
@@ -267,7 +308,7 @@ static int base64_decode_line (char *line, FILE *fp) /*{{{*/
 	bytes[2] |= ch1;
 	fwrite (bytes, 1, 3, fp);
      }
-   
+
    return 0;
 }
 
@@ -278,7 +319,7 @@ static char *fgets_with_counter (char *s, int size, FILE* stream, /*{{{*/
 {
    char *retval;
    int len;
-   
+
    retval = fgets (s, size, stream);
    len = strlen (s);
    if (len && (s[len - 1] == '\n'))
@@ -289,7 +330,7 @@ static char *fgets_with_counter (char *s, int size, FILE* stream, /*{{{*/
      }
    if (c != NULL)
      *c = len;
-   
+
    return retval;
 }
 
@@ -306,7 +347,7 @@ static int decode_base64 (FILE *fp, FILE *fpout, char *line, unsigned int buflen
    int decoding = 0;
    unsigned int len;
    int ret;
-   
+
    while (NULL != fgets_with_counter (line, buflen, fp, &len))
      {
 	if (Base64_Table[(unsigned char) *line] == 0xFF)
@@ -314,23 +355,23 @@ static int decode_base64 (FILE *fp, FILE *fpout, char *line, unsigned int buflen
 	     if (decoding) return 0;
 	     else return -1;
 	  }
-	
+
 	if ((len % 4) != 0)
 	  {
 	     if (decoding) return 0;
 	     else return -1;
 	  }
-	
+
 	ret = base64_decode_line (line, fpout);
 	if (ret)
 	  {
 	     if ((ret == -1) && decoding) ret = 0;
 	     return ret;
 	  }
-	
+
 	decoding = 1;
      }
-   
+
    return 0;
 }
 
@@ -347,43 +388,42 @@ static char *skip_whitespace (char *p) /*{{{*/
 static char *skip_header_string (char *p, char *name) /*{{{*/
 {
    unsigned int len;
-   
+
    p = skip_whitespace (p);
    len = strlen (name);
-   
+
    if (0 != slrn_case_strncmp (p, name, len))
      return NULL;
-   
+
    return p + len;
 }
 
 /*}}}*/
 
-
 static char *skip_beyond_name_eqs (char *p, char *name) /*{{{*/
 {
    int ch;
    unsigned int len;
-   
+
    len = strlen (name);
-   
+
    while (1)
      {
 	p = skip_whitespace (p);
 	if (*p == 0) return NULL;
-	
+
 	if (0 != slrn_case_strncmp ( p,  name, len))
 	  {
 	     while (((ch = *p) != 0) && (ch != ' ') && (ch != '\t') && (ch != '\n'))
 	       p++;
 	     continue;
 	  }
-	
+
 	p = skip_whitespace (p + len);
 	if (*p != '=') continue;
 
 	p = skip_whitespace (p + 1);
-	
+
 	if (*p == 0)
 	  return NULL;
 
@@ -397,18 +437,18 @@ static int parse_name_eqs_int (char *p, char *name, int *val) /*{{{*/
 {
    int ch;
    int ival;
-   
+
    p = skip_beyond_name_eqs (p, name);
    if (p == NULL) return -1;
-   
+
    ival = 0;
-   
+
    while (((ch = *p) != 0) && isdigit(ch))
      {
 	ival = ival * 10 + (ch - '0');
 	p++;
      }
-   
+
    *val = ival;
    return 0;
 }
@@ -420,18 +460,18 @@ static int parse_name_eqs_string (char *p, char *name, char *str, unsigned int l
    char ch;
    char *pmax;
    int quote = 0;
-   
+
    p = skip_beyond_name_eqs (p, name);
    if (p == NULL) return -1;
-   
-   if (*p == '"') 
+
+   if (*p == '"')
      {
 	quote = 1;
 	p++;
      }
-   
+
    pmax = (p + len) - 1;
-   
+
    while ((p < pmax)
 	  && ((ch = *p) != '"')
 	  && (ch != '\n')
@@ -439,19 +479,17 @@ static int parse_name_eqs_string (char *p, char *name, char *str, unsigned int l
      {
 	if ((quote == 0) && ((ch == ' ') || (ch == '\t') || (ch == ';')))
 	  break;
-	
+
 	*str++ = ch;
 	p++;
      }
    *str = 0;
-   
+
    return 0;
 }
 
 /*}}}*/
 
-   
-				   
 static void parse_content_disposition (char *p) /*{{{*/
 {
    (void) parse_name_eqs_string (p, "filename", Base64_Filename, sizeof (Base64_Filename));
@@ -469,12 +507,10 @@ static int is_encoding_base64 (char *p) /*{{{*/
 
 /*}}}*/
 
-
-   
 /* Looking for message/partial; id="bla-bla"; number=10; total=20
- *  The following is from RFC 1522.  It also illustrates what is wrong with 
+ *  The following is from RFC 1522.  It also illustrates what is wrong with
  *  MIME:
- * 
+ *
  *  Three parameters must be specified in the Content-Type field of type
  *  message/partial: The first, "id", is a unique identifier, as close to
  *  a world-unique identifier as possible, to be used to match the parts
@@ -487,24 +523,24 @@ static int is_encoding_base64 (char *p) /*{{{*/
  *  subfield is required on the final part, and is optional (though
  *  encouraged) on the earlier parts.  Note also that these parameters
  *  may be given in any order.
- * 
+ *
  *  Thus, part 2 of a 3-part message may have either of the following
  *  header fields:
- * 
+ *
  *		 Content-Type: Message/Partial;
  *		      number=2; total=3;
  *		      id="oc=jpbe0M2Yt4s@thumper.bellcore.com"
- * 
+ *
  *		 Content-Type: Message/Partial;
  *		      id="oc=jpbe0M2Yt4s@thumper.bellcore.com";
  *		      number=2
- * 
+ *
  *  But part 3 MUST specify the total number of parts:
- * 
+ *
  *		 Content-Type: Message/Partial;
  *		      number=3; total=3;
  *		      id="oc=jpbe0M2Yt4s@thumper.bellcore.com"
- * 
+ *
  *  Note that part numbering begins with 1, not 0.
  */
 
@@ -522,7 +558,7 @@ Mime_Message_Partial_Type;
 static int parse_content_type (char *p, Mime_Message_Partial_Type *mpt) /*{{{*/
 {
 #if 1
-   (void) parse_name_eqs_string (p, "name", 
+   (void) parse_name_eqs_string (p, "name",
 				 Base64_Filename, sizeof (Base64_Filename));
 #endif
    if ((NULL == (p = skip_header_string (p, "message")))
@@ -530,19 +566,19 @@ static int parse_content_type (char *p, Mime_Message_Partial_Type *mpt) /*{{{*/
        || (NULL == (p = skip_header_string (p, "partial")))
        || (NULL == (p = skip_header_string (p, ";"))))
      return -1;
-   
+
    if (-1 == parse_name_eqs_int (p, "number", &mpt->number))
      return -1;
-   
+
    if (-1 == parse_name_eqs_int (p, "total", &mpt->total))
      mpt->total = 0;		       /* not reqired on all parts */
-   
+
    if (-1 == parse_name_eqs_string (p, "id", mpt->id, sizeof (mpt->id)))
      {
 	*mpt->id = 0;
 	return -1;
      }
-   
+
    return 0;
 }
 
@@ -557,28 +593,28 @@ static void read_in_whole_header_line (char *line, FILE *fp) /*{{{*/
    /* We have already read in one line.  Prepare to read in continuation lines */
    len = strlen (line);
    space = MAX_ARTICLE_LINE_LEN - len;
-   
+
    while (space)
      {
 	c = getc (fp);
 	c = ungetc (c, fp);
 	if (c == EOF) return;
-	
-	if ((c != ' ') && (c != '\t')) 
+
+	if ((c != ' ') && (c != '\t'))
 	  {
 	     return;
 	  }
-   
+
 	line += len;
 	if (NULL == fgets (line, space, fp)) return;
-	
+
 	len = strlen (line);
 	space -= len;
      }
 }
 
 /*}}}*/
-   
+
 static int check_and_decode_base64 (FILE *fp, FILE *pipe_fp) /*{{{*/
 {
    char *p;
@@ -587,21 +623,21 @@ static int check_and_decode_base64 (FILE *fp, FILE *pipe_fp) /*{{{*/
    char line[MAX_ARTICLE_LINE_LEN];
    Mime_Message_Partial_Type *current_pmt, pmt_buf;
    int part = 1;
-   
+
    initialize_base64 ();
-   
+
    current_pmt = NULL;
-   
+
    while (NULL != fgets_with_counter (line, sizeof (line), fp, NULL))
      {
 	try_again:
-	
+
 	if (*line == 0)
 	  {
 	     if (found_base64_signature)
 	       {
 		  int ret;
-		  
+
 		  if (*Base64_Filename == 0)
 		    {
 		       slrn_snprintf (Base64_Filename,
@@ -609,18 +645,18 @@ static int check_and_decode_base64 (FILE *fp, FILE *pipe_fp) /*{{{*/
 				      "unknown-64.%d", Base64_Unknown_Number);
 		       Base64_Unknown_Number++;
 		    }
-		  
+
 		  if (fpout == NULL)
 		    fpout = open_output_file (Base64_Filename, "base64", -1, pipe_fp);
-		  
+
 		  if (fpout == NULL) return -1;
-		  
+
 		  ret = decode_base64 (fp, fpout, line, sizeof (line));
 		  /* decode_base64 performs fgets.  So if nothing was decoded
 		   * skip fgets at top of loop
 		   */
 		  if (ret == -1) goto try_again;
-		  
+
 		  if ((current_pmt == NULL)
 		      || (current_pmt->number == current_pmt->total)
 		      || (part != current_pmt->number)
@@ -637,23 +673,23 @@ static int check_and_decode_base64 (FILE *fp, FILE *pipe_fp) /*{{{*/
 	       }
 	     continue;
 	  }
-	
+
 	/* Look for 'Content-' */
-	
+
 	if (slrn_case_strncmp ( "Content-",  line, 8))
 	  continue;
-	
+
 	read_in_whole_header_line (line, fp);
-	
+
 	p = line + 8;
-	
+
 	if (0 == slrn_case_strncmp ( p,  "Transfer-Encoding: ", 19))
 	  {
 	     if (is_encoding_base64 (p + 19))
 	       {
 		  if (found_base64_signature)
 		    {
-		       if (fpout != NULL) 
+		       if (fpout != NULL)
 			 {
 			    uudecode_fclose (fpout, pipe_fp);
 			    fpout = NULL;
@@ -666,13 +702,13 @@ static int check_and_decode_base64 (FILE *fp, FILE *pipe_fp) /*{{{*/
 	       }
 	     continue;
 	  }
-	    
+
 	if (0 == slrn_case_strncmp (p, "Disposition: ", 13))
 	  {
 	     parse_content_disposition (p + 13);
 	     continue;
 	  }
-	
+
 	if (0 == slrn_case_strncmp (p, "Type: ", 6))
 	  {
 	     Mime_Message_Partial_Type pmt;
@@ -682,7 +718,7 @@ static int check_and_decode_base64 (FILE *fp, FILE *pipe_fp) /*{{{*/
 		  /* current_pmt = NULL; */
 		  continue;
 	       }
-	     
+
 	     if ((current_pmt == NULL)
 		 || (pmt.number == 1)
 		 || (part != pmt.number)
@@ -702,7 +738,7 @@ static int check_and_decode_base64 (FILE *fp, FILE *pipe_fp) /*{{{*/
 	     continue;
 	  }
      }
-   
+
    uudecode_fclose (fpout, pipe_fp);
    return 0;
 }
@@ -713,7 +749,7 @@ static int parse_uuencode_begin_line (char *b, char **file, int *mode) /*{{{*/
 {
    int m = 0;
    char *bmax;
-   
+
    while (*b == ' ') b++;
    if (0 == isdigit (*b)) return -1;
    while (isdigit (*b))
@@ -722,14 +758,14 @@ static int parse_uuencode_begin_line (char *b, char **file, int *mode) /*{{{*/
 	b++;
      }
    if (*b != ' ') return -1;
-   
+
    while (*b == ' ') b++;
-   
+
    if (*b < ' ') return -1;
-	
+
    bmax = b + strlen (b);
    while ((unsigned char)*bmax <= ' ') *bmax-- = 0;
-   
+
    *mode = m;
    *file = (char *) b;
    return 0;
@@ -737,19 +773,19 @@ static int parse_uuencode_begin_line (char *b, char **file, int *mode) /*{{{*/
 
 /*}}}*/
 
-static int check_and_uudecode (FILE *fp, FILE *pipe_fp, 
+static int check_and_uudecode (FILE *fp, FILE *pipe_fp,
 			       int no_slop) /*{{{*/
 {
    FILE *outfp = NULL;
    int is_mbox = -1;
    char buf[MAX_ARTICLE_LINE_LEN];
-   
+
    while (NULL != fgets (buf, sizeof (buf), fp))
      {
 	char *file;
 	int mode = 0;
 	unsigned int buflen;
-	
+
 	if (is_mbox == -1)
 	  {
 	     if ((!strncmp (buf, "From", 4)) &&
@@ -791,7 +827,7 @@ static int check_and_uudecode (FILE *fp, FILE *pipe_fp,
 	  {
 	     unsigned int len, write_len;
 	     unsigned char out[60], *outp, *outmax, *b, *bmax;
-	     
+
 	     if ((is_mbox) && (!strncmp (buf, "From", 4)) &&
 		 ((unsigned char)buf[4] <= ' '))
 	       {
@@ -807,7 +843,7 @@ static int check_and_uudecode (FILE *fp, FILE *pipe_fp,
 		  while (buflen);
 		  continue;
 	       }
-	     
+
 	     if (((*buf & 0x3F) == ' ') && ((*buf + 1) == '\0'))
 	       {
 		  /* we may be on the last line before the end.  Lets check */
@@ -817,7 +853,7 @@ static int check_and_uudecode (FILE *fp, FILE *pipe_fp,
 		       slrn_error (_("Unexpected end of file.\n"));
 		       return -1;
 		    }
-		  
+
 		  if (!strcmp (buf, "end"))
 		    {
 		       uudecode_fclose (outfp, pipe_fp);
@@ -825,7 +861,7 @@ static int check_and_uudecode (FILE *fp, FILE *pipe_fp,
 		       break;
 		    }
 	       }
-	     
+
 	     /* Now perform some sanity checking */
 	     len = *buf;
 
@@ -848,19 +884,19 @@ static int check_and_uudecode (FILE *fp, FILE *pipe_fp,
 
 		  if (NULL == (outfp = open_output_file (file, "uuencoded", mode, pipe_fp)))
 		    return -1;
-		    
+
 		  continue;
 	       }
-	     
+
 	     buflen--;
 	     len -= ' ';
-	     
+
 	     /* In general, I cannot make the test:
 	      * @ if ((3 * buflen) != (len * 4)) continue;
 	      * The problem is that the last line may be padded.  Instead, do
 	      * it just for normal length lines and handle padding for others.
 	      */
-	     
+
 	     if (*buf == 'M')
 	       {
 		  if ((3 * buflen) != (len * 4)) continue;
@@ -871,13 +907,13 @@ static int check_and_uudecode (FILE *fp, FILE *pipe_fp,
 	       }
 	     else
 	       {
-		  unsigned int buflen1 = ((len + 2) / 3) * 4; 
+		  unsigned int buflen1 = ((len + 2) / 3) * 4;
 		  if (buflen != buflen1)
 		    {
 		       if (no_slop) continue;
 #if 0
 #ifdef STANDALONE
-		       slrn_message_now (_("uuencode line appears corrupt: \"%s\""), 
+		       slrn_message_now (_("uuencode line appears corrupt: \"%s\""),
 					 buf);
 #endif
 #endif
@@ -886,7 +922,7 @@ static int check_and_uudecode (FILE *fp, FILE *pipe_fp,
 	       }
 	     b = (unsigned char *) buf + 1;
 	     bmax = b + buflen;
-	     
+
 	     while (b < bmax)
 	       {
 		  *b = (*b - 32) & 0x3F;
@@ -895,9 +931,9 @@ static int check_and_uudecode (FILE *fp, FILE *pipe_fp,
 		  *(b + 3) = (*(b + 3) - 32) & 0x3F;
 		  b += 4;
 	       }
-	     
+
 	     b = (unsigned char *) buf + 1;
-	     
+
 	     outp = out;
 	     outmax = outp + len;
 	     while (outp < outmax)
@@ -905,10 +941,9 @@ static int check_and_uudecode (FILE *fp, FILE *pipe_fp,
 		  register unsigned char b1, b2;
 		  b1 = *(b + 1);
 		  b2 = *(b + 2);
-		  
-		  
+
 		  *outp++ = (*b << 2) | (b1 >> 4);
-		  
+
 		  if (outp < outmax)
 		    {
 		       *outp++ = (b1 << 4) | (b2 >> 2);
@@ -917,21 +952,21 @@ static int check_and_uudecode (FILE *fp, FILE *pipe_fp,
 		    }
 		  b += 4;
 	       }
-	     
+
 	     if (len != (write_len = fwrite ((char *) out, 1, len, outfp)))
 	       {
-		  slrn_error (_("write to file failed (%u/%u bytes)\n"), 
+		  slrn_error (_("write to file failed (%u/%u bytes)\n"),
 			      write_len, len);
 		  uudecode_fclose (outfp, pipe_fp);
 		  return -1;
 	       }
 	  }
 	/* end of part reading */
-	
+
 	/* back to looking for something else */
      }
-   
-   if (outfp != NULL) 
+
+   if (outfp != NULL)
      {
 	uudecode_fclose (outfp, pipe_fp);
 	outfp = NULL;
@@ -946,7 +981,7 @@ static int decode_best_guess (FILE *fp, FILE *pipe_fp, int no_slop) /*{{{*/
    int ch;
    int nl_seen = 1;
    char *mime_ptr;
-   
+
    while (EOF != (ch = getc (fp)))
      {
 	if (ch == '\n')
@@ -954,32 +989,32 @@ static int decode_best_guess (FILE *fp, FILE *pipe_fp, int no_slop) /*{{{*/
 	     nl_seen = 1;
 	     continue;
 	  }
-	
+
 	if (nl_seen == 0)
 	  continue;
-	
+
 	if (ch == 'b')
 	  {
 	     ungetc (ch, fp);
 	     return check_and_uudecode (fp, pipe_fp, no_slop);
 	  }
-	
+
 	nl_seen = 0;
-	
+
 	mime_ptr = "mime-version:";
 	while (1)
 	  {
-	     if ((ch | 0x20) != *mime_ptr) 
+	     if ((ch | 0x20) != *mime_ptr)
 	       break;
-	     
+
 	     mime_ptr++;
 	     if (*mime_ptr == ':')
 	       {
 		  return check_and_decode_base64 (fp, pipe_fp);
 	       }
-	     
+
 	     ch = getc (fp);
-	     
+
 	     if (ch == EOF) break;
 	     if (ch == '\n')
 	       {
@@ -1001,7 +1036,7 @@ int slrn_uudecode_file (char *file, char *newdir, /*{{{*/
 #ifndef STANDALONE
    char olddir_buf[SLRN_MAX_PATH_LEN + 1];
    char newdir_buf[SLRN_MAX_PATH_LEN + 1];
-#endif	
+#endif
    int ret;
    int no_slop = 0;		       /* Set to 1 for up-to-spec files */
 
@@ -1021,14 +1056,14 @@ int slrn_uudecode_file (char *file, char *newdir, /*{{{*/
    if (NULL == slrn_getcwd (olddir_buf, sizeof(olddir_buf)))
      return -1;
 #endif
-   
+
    if ((newdir != NULL)
        && (-1 == slrn_chdir(newdir)))
      return -1;
-   
+
    if (file == NULL) fp = stdin;
    else fp = fopen (file, "r");
-   
+
    if (fp == NULL)
      {
 	slrn_error(_("Unable to open %s.\n"), file);
@@ -1040,7 +1075,7 @@ int slrn_uudecode_file (char *file, char *newdir, /*{{{*/
 
    if (base64_only == -1)
      ret = decode_best_guess (fp, pipe_fp, no_slop);
-   else if (base64_only == 0) 
+   else if (base64_only == 0)
      {
 	ret = check_and_uudecode (fp, pipe_fp, no_slop);
 	if ((ret == 0) && (fp != stdin))
@@ -1050,14 +1085,14 @@ int slrn_uudecode_file (char *file, char *newdir, /*{{{*/
 	  }
      }
    else ret = check_and_decode_base64 (fp, pipe_fp);
-   
+
    if (fp != stdin)
      fclose (fp);
-   
+
 #ifdef STANDALONE
    if (pipe_fp == NULL) slrn_message (_("No more files found.\n"));
 #endif
-   
+
 #ifndef STANDALONE
    if (-1 == slrn_chdir (olddir_buf))
      {
@@ -1082,7 +1117,7 @@ static void usage (void) /*{{{*/
 void slrn_error (char *fmt, ...)
 {
    va_list ap;
-   
+
    if (fmt != NULL)
      {
 	va_start (ap, fmt);
@@ -1095,7 +1130,7 @@ void slrn_error (char *fmt, ...)
 void slrn_exit_error (char *fmt, ...)
 {
    va_list ap;
-   
+
    if (fmt != NULL)
      {
 	va_start (ap, fmt);
@@ -1120,7 +1155,7 @@ int main (int argc, char **argv) /*{{{*/
    bindtextdomain(NLS_PACKAGE_NAME,NLS_LOCALEDIR);
    textdomain(NLS_PACKAGE_NAME);
 #endif
-   
+
    SLang_init_case_tables ();
 
    while (argc > 1)
@@ -1130,7 +1165,7 @@ int main (int argc, char **argv) /*{{{*/
 	     usage ();
 	     return 1;
 	  }
-	
+
 	if (!strcmp ("-64", argv[1]))
 	  {
 	     base64_only = 1;
@@ -1151,7 +1186,7 @@ int main (int argc, char **argv) /*{{{*/
 	  }
 	else break;
      }
-   
+
    if (argc <= 1)
      {
 	if (0 == isatty (fileno(stdin)))
@@ -1161,7 +1196,7 @@ int main (int argc, char **argv) /*{{{*/
 	usage ();
 	return 1;
      }
-   
+
    for (i = 1; i < argc; i++)
      {
 	slrn_uudecode_file (argv[i], NULL, base64_only, pipe_fp);
