@@ -1,7 +1,7 @@
 /*
  This file is part of SLRN.
 
- Copyright (c) 1994, 1999, 2007-2008 John E. Davis <jed@jedsoft.org>
+ Copyright (c) 1994, 1999, 2007-2016 John E. Davis <jed@jedsoft.org>
 
  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
@@ -15,7 +15,7 @@
 
  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
- 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef SLRNPULL_CODE
 # include "config.h"
@@ -36,11 +36,11 @@ unsigned long slrn_compute_hash (unsigned char *s, unsigned char *smax)
 {
    register unsigned long h = 0, g;
    register unsigned long sum = 0;
-   
+
    while (s < smax)
      {
 	sum += *s++ | 0x20;	       /* case-insensitive */
-	
+
 	h = sum + (h << 3);
 	if ((g = h & 0xE0000000U) != 0)
 	  {
@@ -76,11 +76,11 @@ Newsgroup_Cache_Type;
 static Msg_Id_Cache_Type *Msg_Id_Cache [MAX_MSGID_HASH];
 static Newsgroup_Cache_Type *Newsgroup_Cache [MAX_NG_HASH];
 
-static unsigned int simple_hash (unsigned char *s, unsigned char *smax, 
+static unsigned int simple_hash (unsigned char *s, unsigned char *smax,
 				 unsigned int mod)
 {
    register unsigned int h = 0;
-   
+
    while (s < smax)
      {
 	h = ((h << 5) + *s) % mod;
@@ -94,22 +94,22 @@ static char *allocate_newsgroup (char *newsgroup)
    Newsgroup_Cache_Type *node;
    unsigned int hash_index;
    unsigned int len;
-   
+
    len = strlen (newsgroup);
-   
+
    hash_index = simple_hash ((unsigned char *) newsgroup,
 			     (unsigned char *) newsgroup + len,
 			     MAX_NG_HASH);
-   
+
    node = Newsgroup_Cache [hash_index];
-   
+
    while (node != NULL)
      {
 	if (!strcmp (node->newsgroup, newsgroup))
 	  return node->newsgroup;
 	node = node->next;
      }
-   
+
    node = (Newsgroup_Cache_Type *) slrn_malloc (sizeof (Newsgroup_Cache_Type),1,1);
    if (node == NULL) return NULL;
    if (NULL == (node->newsgroup = (char *) slrn_malloc (len + 1,0,1)))
@@ -118,29 +118,27 @@ static char *allocate_newsgroup (char *newsgroup)
 	return NULL;
      }
    strcpy (node->newsgroup, newsgroup); /* safe */
-   
+
    node->next = Newsgroup_Cache [hash_index];
    Newsgroup_Cache [hash_index] = node;
-   
+
    return node->newsgroup;
 }
 
-   
-   
-static Msg_Id_Cache_Type *allocate_msgid_node (char *msgid, unsigned int msgid_len, 
+static Msg_Id_Cache_Type *allocate_msgid_node (char *msgid, unsigned int msgid_len,
 					       char *newsgroup)
 {
    Msg_Id_Cache_Type *node;
    char *buf;
-   
+
    newsgroup = allocate_newsgroup (newsgroup);
    if (newsgroup == NULL)
      return NULL;
-   
+
    buf = (char *) slrn_malloc (msgid_len + 1, 0, 1);
    if (buf == NULL) return NULL;
    slrn_strncpy (buf, msgid, msgid_len);
-   
+
    node = (Msg_Id_Cache_Type *) slrn_malloc (sizeof (Msg_Id_Cache_Type), 1, 1);
    if (node == NULL)
      {
@@ -159,30 +157,30 @@ static Msg_Id_Cache_Type *is_msgid_cached (char *msgid, char *newsgroup,
    Msg_Id_Cache_Type *node;
    unsigned int hash_index;
    unsigned int msgid_len;
-   
+
 #ifndef SLRNPULL_CODE
    (void) num;
 #endif
 
    msgid_len = strlen (msgid);
-   
-   hash_index = simple_hash ((unsigned char *) msgid, 
+
+   hash_index = simple_hash ((unsigned char *) msgid,
 			     (unsigned char *) msgid + msgid_len,
 			     MAX_MSGID_HASH);
 
    node = Msg_Id_Cache [hash_index];
-   
+
    while (node != NULL)
      {
 	if (!strcmp (node->msgid, msgid))
 	  return node;
 	node = node->next;
      }
-   
+
    if (add && (Dont_Grow == 0) && (newsgroup != NULL))
      {
 	node = allocate_msgid_node (msgid, msgid_len, newsgroup);
-	
+
 	if (node == NULL) Dont_Grow = 1;
 	else
 	  {
@@ -193,14 +191,14 @@ static Msg_Id_Cache_Type *is_msgid_cached (char *msgid, char *newsgroup,
 	     Msg_Id_Cache [hash_index] = node;
 	  }
      }
-   
+
    return NULL;
 }
 
 char *slrn_is_msgid_cached (char *msgid, char *newsgroup, int add)
 {
    Msg_Id_Cache_Type *node;
-   
+
    node = is_msgid_cached (msgid, newsgroup, 0, add);
 
    if (node != NULL)
@@ -208,7 +206,7 @@ char *slrn_is_msgid_cached (char *msgid, char *newsgroup, int add)
 
    return NULL;
 }
-   
+
 #endif				       /* SLRN_HAS_MSGID_CACHE */
 
 #if 0
@@ -221,20 +219,20 @@ int main (int argc, char **argv)
    unsigned char *b, ch;
    unsigned long hash;
    int i;
-   
+
    while (NULL != fgets ((char *) buf, sizeof (buf) - 1, stdin))
      {
 	b = buf;
 	while (((ch = *b) != '!') && (ch != ':') && (ch > ' '))
 	  b++;
-	
+
 	hash = slrn_compute_hash (buf, b);
 	hash = hash % SIZE;
-	
+
 	/* fprintf (stdout, "%X\n", hash); */
 	bin[hash] += 1;
      }
-   
+
    for (i = 0; i < SIZE; i++)
      {
 	fprintf (stdout, "%d\t%d\n", i, bin[i]);
