@@ -1,8 +1,8 @@
 /*
  This file is part of SLRN.
 
- Copyright (c) 1994, 1999 John E. Davis <davis@space.mit.edu>
- Copyright (c) 2001-2004 Thomas Schultz <tststs@gmx.de>
+ Copyright (c) 1994, 1999, 2007-2016 John E. Davis <jed@jedsoft.org>
+ Copyright (c) 2001-2006 Thomas Schultz <tststs@gmx.de>
 
  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
@@ -16,7 +16,7 @@
 
  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
- 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #include "config.h"
 #include "slrnfeat.h"
@@ -64,7 +64,7 @@ static void _nntp_connection_lost_hook (NNTP_Type *s)
 	if ((_NNTP_Abort_On_Disconnection == -1) && SLKeyBoard_Quit)
 	  return;
 
-	slrn_exit_error (_("Server connection to %s lost.  Cannot recover."), 
+	slrn_exit_error (_("Server connection to %s lost.  Cannot recover."),
 			 s->host);
      }
 }
@@ -73,7 +73,7 @@ static int _nntp_interrupt_handler (void)
 {
    (void) slrn_handle_interrupts ();
 
-   if ((SLang_Error == USER_BREAK) || SLKeyBoard_Quit)
+   if ((SLang_get_error () == USER_BREAK) || SLKeyBoard_Quit)
      return -1;
 
    return 0;
@@ -82,18 +82,17 @@ static int _nntp_interrupt_handler (void)
 static void _nntp_reset (void)
 {
    NNTP_Type *s = NNTP_Server;
-   
+
    nntp_disconnect_server (s);
    /* The next NNTP command will actually perform the reset. */
 }
 
-   
 static void _nntp_close_server (void)
 {
    NNTP_Type *s = NNTP_Server;
-   
+
    NNTP_Server = NULL;
-   
+
    if (s != NULL) nntp_close_server (s);
 }
 
@@ -101,31 +100,53 @@ static int _nntp_initialize_server (void)
 {
    NNTP_Authorization_Hook = slrn_get_authorization;
    SLTCP_Interrupt_Hook = _nntp_interrupt_handler;
-   
+
    if (NNTP_Server != NULL)
      nntp_close_server (NNTP_Server);
-   
+
    if (NULL == (NNTP_Server = nntp_open_server (NNTP_Server_Name, NNTP_Port)))
      return -1;
-   
-   if (Slrn_Prefer_Head == 2)
+
+   NNTP_Server_Obj.sv_has_xover = 0;
+   if (Slrn_Prefer_Head & 2)
      NNTP_Server->can_xover = 0;
-   else if (-1 == nntp_has_cmd (NNTP_Server, "XOVER"))
+   else
      {
-	_nntp_close_server ();
-	return -1;
+	if (-1 == nntp_has_cmd (NNTP_Server, "XOVER"))
+	  {
+	     _nntp_close_server ();
+	     return -1;
+	  }
+
+	if (NNTP_Server->can_xover == 0)
+	  {
+	     slrn_message_now (_("Server %s does not implement the XOVER command."),
+			       NNTP_Server->host);
+	  }
+	else NNTP_Server_Obj.sv_has_xover = 1;
      }
-   
-   if (NNTP_Server->can_xover == 0)
+
+   NNTP_Server_Obj.sv_has_xhdr = 0;
+   if (Slrn_Prefer_Head & 1)
+     NNTP_Server->can_xhdr = 0;
+   else
      {
-	slrn_message_now (_("Server %s does not implement the XOVER command."), 
-			  NNTP_Server->host);
-	NNTP_Server_Obj.sv_has_xover = 0;
+	if (-1 == nntp_has_cmd (NNTP_Server, "XHDR Path"))
+	  {
+	     _nntp_close_server ();
+	     return -1;
+	  }
+
+	if (NNTP_Server->can_xhdr == 0)
+	  {
+	     slrn_message_now (_("Server %s does not implement the XHDR command."),
+			       NNTP_Server->host);
+	  }
+	else NNTP_Server_Obj.sv_has_xhdr = 1;
      }
-   else NNTP_Server_Obj.sv_has_xover = 1;
-   
+
    NNTP_Server_Obj.sv_id = NNTP_Server->sv_id;
-   
+
    NNTP_Post_Obj.po_can_post = NNTP_Server->can_post;
    NNTP_Server->flags |= NNTP_RECONNECT_OK;
 
@@ -133,16 +154,15 @@ static int _nntp_initialize_server (void)
    return 0;
 }
 
-
 static int _nntp_read_line (char *buf, unsigned int len)
 {
    int status;
-   
+
    status = nntp_read_line (NNTP_Server, buf, len);
-   
+
    if (status == 1)
      return status;
-   
+
    if (status == 0)
      {
 	_NNTP_Abort_On_Disconnection = 0;
@@ -154,24 +174,24 @@ static int _nntp_read_line (char *buf, unsigned int len)
    return -1;
 }
 
-static int _nntp_get_article_size (int id)
+static int _nntp_get_article_size (NNTP_Artnum_Type id)
 {
    /* no nntp-command for this, reading the article takes too much time */
    (void) id;
    return 0;
 }
 
-static int _nntp_head_cmd (int id, char *msgid, int *real_idp)
+static int _nntp_head_cmd (NNTP_Artnum_Type id, char *msgid, NNTP_Artnum_Type *real_idp)
 {
    return nntp_head_cmd (NNTP_Server, id, msgid, real_idp);
 }
 
-static int _nntp_select_article (int n, char *msgid)
+static int _nntp_select_article (NNTP_Artnum_Type n, char *msgid)
 {
    return nntp_article_cmd (NNTP_Server, n, msgid);
 }
 
-static int _nntp_select_group (char *grp, int *min, int *max)
+static int _nntp_select_group (char *grp, NNTP_Artnum_Type *min, NNTP_Artnum_Type *max)
 {
    return nntp_select_group (NNTP_Server, grp, min, max);
 }
@@ -189,7 +209,7 @@ static char *_nntp_current_group (void)
 static int _nntp_put_server_cmd (char *cmd, char *buf, unsigned int len)
 {
    int code;
-   
+
    if (-1 != (code = nntp_server_cmd (NNTP_Server, cmd)))
      {
 	strncpy (buf, NNTP_Server->rspbuf, len);
@@ -198,12 +218,12 @@ static int _nntp_put_server_cmd (char *cmd, char *buf, unsigned int len)
    return code;
 }
 
-static int _nntp_xpat_cmd (char *hdr, int rmin, int rmax, char *pat)
+static int _nntp_xpat_cmd (char *hdr, NNTP_Artnum_Type rmin, NNTP_Artnum_Type rmax, char *pat)
 {
    return nntp_xpat_cmd (NNTP_Server, hdr, rmin, rmax, pat);
 }
 
-static int _nntp_one_xhdr_cmd (char *hdr, int num, 
+static int _nntp_one_xhdr_cmd (char *hdr, NNTP_Artnum_Type num,
 			       char *buf, unsigned int buflen)
 {
    return nntp_one_xhdr_cmd (NNTP_Server, hdr, num, buf, buflen);
@@ -227,9 +247,9 @@ static int _nntp_list_newsgroups (void)
 static int _nntp_list_active (char *pat)
 {
    int code;
-   
+
    code = nntp_list_active_cmd (NNTP_Server, pat);
-   
+
    if (OK_GROUPS == code)
      _NNTP_Abort_On_Disconnection = (pat == NULL) ? 1 : -1;
 
@@ -238,7 +258,7 @@ static int _nntp_list_active (char *pat)
 
 static int _nntp_send_authinfo (void)
 {
-   return nntp_authorization (NNTP_Server);
+   return nntp_authorization (NNTP_Server, Slrn_Force_Authentication);
 }
 
 static int _nntp_start_post (void)
@@ -260,15 +280,15 @@ static int _nntp_start_post (void)
 static int _nntp_end_post (void)
 {
    int status;
-   
+
    status = nntp_end_post (NNTP_Server);
-   
+
    if (status == -1)
      {
 	slrn_error (_("Error writing to server."));
 	return -1;
      }
-   
+
    if (NNTP_Server->code != OK_POSTED)
      {
 	slrn_error (_("Article rejected: %s"), NNTP_Server->rspbuf);
@@ -278,25 +298,24 @@ static int _nntp_end_post (void)
    return 0;
 }
 
-
 static int _nntp_po_puts (char *buf)
 {
    char *b;
-   
+
    /* make sure \n --> \r\n */
    b = buf;
-   while (NULL != (b = slrn_strchr (buf, '\n')))
+   while (NULL != (b = slrn_strbyte (buf, '\n')))
      {
 	unsigned int len;
-	
+
 	len = (unsigned int) (b - buf);
 	if ((-1 == nntp_write_server (NNTP_Server, buf, len))
 	    || (-1 == nntp_write_server (NNTP_Server, "\r\n", 2)))
 	  return -1;
-	
+
 	buf = b + 1;
      }
-   
+
    return nntp_fputs_server (NNTP_Server, buf);
 }
 
@@ -321,7 +340,7 @@ static int _nntp_po_printf (char *fmt, ...)
    return retval;
 }
 
-static int _nntp_xover_cmd (int min, int max)
+static int _nntp_xover_cmd (NNTP_Artnum_Type min, NNTP_Artnum_Type max)
 {
    int status;
 
@@ -329,23 +348,23 @@ static int _nntp_xover_cmd (int min, int max)
      {
 	_NNTP_Abort_On_Disconnection = -1;
      }
-   
+
    return status;
 }
 
-static int _nntp_xhdr_cmd (char *field, int min, int max)
+static int _nntp_xhdr_cmd (char *field, NNTP_Artnum_Type min, NNTP_Artnum_Type max)
 {
    int status;
-   
+
    if (OK_HEAD == (status = nntp_xhdr_cmd (NNTP_Server, field, min, max)))
      {
 	_NNTP_Abort_On_Disconnection = -1;
      }
-   
+
    return status;
 }
 
-static int _nntp_next_cmd (int *id)
+static int _nntp_next_cmd (NNTP_Artnum_Type *id)
 {
    return nntp_next_cmd (NNTP_Server, id);
 }
@@ -353,30 +372,43 @@ static int _nntp_next_cmd (int *id)
 static unsigned int _nntp_get_bytes (int clear)
 {
    unsigned int temp;
-   
+
    temp = NNTP_Server->number_bytes_received;
    if (clear)
      NNTP_Server->number_bytes_received = 0;
-   
+
    return temp;
 }
 
 static char * _nntp_get_recom_id (void)
 {
    SLRegexp_Type *re;
-   
+
    if ((re=slrn_compile_regexp_pattern("<.*@.*\\..*>")) != NULL)
      {
-	char *t, *msgid, *post_rsp;
+	char *t, *msgid = NULL, *post_rsp;
 	post_rsp = NNTP_Server->rspbuf;
+#if SLANG_VERSION < 20000
 	t=(char*)SLang_regexp_match((unsigned char*) post_rsp,
 				    strlen(post_rsp), re);
+#else
+	t = SLregexp_match (re, post_rsp, strlen (post_rsp));
+#endif
 	if (t != NULL)
 	  {
-	     if ((msgid=slrn_strnmalloc(t, re->end_matches[0],1)) == NULL)
-	       return NULL;
-	     return msgid;
+	     unsigned int len;
+#if SLANG_VERSION < 20000
+	     len = re->end_matches[0];
+#else
+	     (void) SLregexp_nth_match (re, 0, NULL, &len);
+#endif
+
+	     msgid=slrn_strnmalloc(t, len, 1);
 	  }
+#if SLANG_VERSION >= 20000
+	SLregexp_free (re);
+#endif
+	return msgid;
      }
    return NULL;
 }
@@ -390,7 +422,7 @@ static int nntp_init_objects (void)
    NNTP_Post_Obj.po_puts = _nntp_po_puts;
    NNTP_Post_Obj.po_get_recom_id = _nntp_get_recom_id;
    NNTP_Post_Obj.po_can_post = 1;
-   
+
    NNTP_Server_Obj.sv_select_group = _nntp_select_group;
    NNTP_Server_Obj.sv_refresh_groups = _nntp_refresh_groups;
    NNTP_Server_Obj.sv_current_group = _nntp_current_group;
@@ -407,7 +439,7 @@ static int nntp_init_objects (void)
    NNTP_Server_Obj.sv_list_newsgroups = _nntp_list_newsgroups;
    NNTP_Server_Obj.sv_list_active = _nntp_list_active;
    NNTP_Server_Obj.sv_send_authinfo = _nntp_send_authinfo;
-   
+
    NNTP_Server_Obj.sv_has_xover = 0;
    NNTP_Server_Obj.sv_has_xhdr = -1;
    NNTP_Server_Obj.sv_nntp_xover = _nntp_xover_cmd;
@@ -423,26 +455,25 @@ static int nntp_init_objects (void)
 static int _nntp_get_server_name (void)
 {
    char *host;
-   
+
    if (NULL == (host = NNTP_Server_Name))
      {
 	host = nntp_get_server_name ();
 	if (host == NULL)
 	  return -1;
      }
-   
+
    NNTP_Server_Name = NNTP_Server_Obj.sv_name = slrn_safe_strmalloc (host);
    return 0;
 }
 
-
 static int nntp_select_server_object (void)
 {
    if (NNTP_Server_Obj.sv_select_group == NULL)
      nntp_init_objects ();
-   
+
    Slrn_Server_Obj = &NNTP_Server_Obj;
-   
+
    if (NNTP_Server_Obj.sv_name == NULL)
      return _nntp_get_server_name ();
 
@@ -453,12 +484,12 @@ static int nntp_select_post_object (void)
 {
    if (NNTP_Post_Obj.po_start == NULL)
      nntp_init_objects ();
-   
+
    Slrn_Post_Obj = &NNTP_Post_Obj;
-   
+
    if (NNTP_Server_Obj.sv_name == NULL)
      return _nntp_get_server_name ();
-   
+
    return 0;
 }
 
@@ -477,7 +508,7 @@ static void nntp_usage (void)
 static int nntp_parse_args (char **argv, int argc)
 {
    int i;
-   
+
    for (i = 0; i < argc; i++)
      {
 	if (!strcmp (argv[i], "--help"))
@@ -485,7 +516,7 @@ static int nntp_parse_args (char **argv, int argc)
 	else if (i + 1 < argc)
 	  {
 	     char *arg, *arg1;
-	     
+
 	     arg = argv[i];
 	     arg1 = argv [i + 1];
 	     if (!strcmp ("-p", arg))
@@ -502,6 +533,6 @@ static int nntp_parse_args (char **argv, int argc)
 	  }
 	else break;
      }
-   
+
    return i;
 }
