@@ -1,7 +1,7 @@
 /*
  This file is part of SLRN.
 
- Copyright (c) 1994, 1999, 2007-2008 John E. Davis <jed@jedsoft.org>
+ Copyright (c) 1994, 1999, 2007-2016 John E. Davis <jed@jedsoft.org>
  Copyright (c) 2001-2006 Thomas Schultz <tststs@gmx.de>
 
  This program is free software; you can redistribute it and/or modify it
@@ -16,13 +16,13 @@
 
  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
- 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef _SLRN_NNTPLIB_H
 #define _SLRN_NNTPLIB_H
 #include "sltcp.h"
 
-typedef struct 
+typedef struct
 {
 #define NNTP_RECONNECT_OK	0x1
    unsigned int flags;
@@ -45,11 +45,11 @@ typedef struct
    int can_xhdr;
    int can_xpat;
    int sv_id; /* type of server software */
-   
+
    int (*auth_hook)(char *, char **, char **);
 
    int number_bytes_received;
-   
+
    SLTCP_Type *tcp;
 }
 NNTP_Type;
@@ -58,8 +58,6 @@ extern void nntp_disconnect_server (NNTP_Type *);
 extern int nntp_check_connection (NNTP_Type *);
 extern int nntp_reconnect_server (NNTP_Type *);
 
-extern int nntp_server_cmd (NNTP_Type *, char *);
-extern int nntp_server_vcmd (NNTP_Type *, char *, ...) ATTRIBUTE_PRINTF(2,3);
 extern int nntp_write_server (NNTP_Type *, char *, unsigned int);
 extern int nntp_fgets_server (NNTP_Type *, char *, unsigned int);
 extern int nntp_fputs_server (NNTP_Type *, char *);
@@ -79,7 +77,6 @@ extern NNTP_Type *nntp_open_server (char *, int);
 extern int nntp_read_line (NNTP_Type *s, char *, unsigned int);
 extern int nntp_discard_output (NNTP_Type *s);
 
-
 extern int nntp_has_cmd (NNTP_Type *, char *);
 extern int nntp_list (NNTP_Type *, char *);
 extern int nntp_list_newsgroups (NNTP_Type *);
