@@ -1,7 +1,7 @@
 /*
  This file is part of SLRN.
 
- Copyright (c) 1994, 1999, 2007-2008 John E. Davis <jed@jedsoft.org>
+ Copyright (c) 1994, 1999, 2007-2016 John E. Davis <jed@jedsoft.org>
  Copyright (c) 2001-2006 Thomas Schultz <tststs@gmx.de>
 
  This program is free software; you can redistribute it and/or modify it
@@ -16,14 +16,14 @@
 
  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
- 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef _SLRN_SERVER_H
 #define _SLRN_SERVER_H
 #include "nntpcodes.h"
 #include "ranges.h"
 
-typedef struct 
+typedef struct
 {
    int (*po_start)(void);
    int (*po_end)(void);
@@ -34,7 +34,7 @@ typedef struct
    int po_can_post;
 } Slrn_Post_Obj_Type;
 
-typedef struct 
+typedef struct
 {
    int (*sv_select_group) (char *, NNTP_Artnum_Type *, NNTP_Artnum_Type *);
    int (*sv_refresh_groups) (Slrn_Group_Range_Type *, int);
@@ -62,7 +62,7 @@ typedef struct
    int sv_has_xhdr;
    int sv_has_xover;
    int sv_reset_has_xover;
-   /* if non-zero, sv_has_xover is set to 1 when entering a group.  
+   /* if non-zero, sv_has_xover is set to 1 when entering a group.
     * This is because some servers support XOVER but do not have overview
     * files for all groups.  See xover.c
     */
@@ -80,7 +80,7 @@ typedef struct
 #define SERVER_ID_INN		1
    int sv_id;
    char *sv_name;
-} 
+}
 Slrn_Server_Obj_Type;
 
 extern Slrn_Server_Obj_Type *Slrn_Server_Obj;
