@@ -1,7 +1,7 @@
 /*
  This file is part of SLRN.
 
- Copyright (c) 1994, 1999, 2007-2008 John E. Davis <jed@jedsoft.org>
+ Copyright (c) 1994, 1999, 2007-2016 John E. Davis <jed@jedsoft.org>
  Copyright (c) 2001-2006 Thomas Schultz <tststs@gmx.de>
 
  This program is free software; you can redistribute it and/or modify it
@@ -16,7 +16,7 @@
 
  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
- 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 extern int slrn_read_startup_file (char *);
 extern void slrn_startup_initialize (void);
@@ -34,8 +34,10 @@ extern int slrn_set_object_color (char *, char *, char *, SLtt_Char_Type);
 extern char *slrn_get_object_color (char *, int);
 extern int slrn_add_to_server_list (char *, char *, char *, char *);
 
-struct SLcmd_Cmd_Table_Type;
-struct SLRegexp_Type;
+extern char *slrn_get_charset (char *name);
+
+/* struct SLcmd_Cmd_Table_Type; */
+/* struct SLRegexp_Type; */
 extern void slrn_generic_regexp_fun (int, SLcmd_Cmd_Table_Type *, SLRegexp_Type **);
 
 typedef struct Slrn_Int_Var_Type
