@@ -1,7 +1,7 @@
 /*
  This file is part of SLRN.
 
- Copyright (c) 1994, 1999, 2007-2008 John E. Davis <jed@jedsoft.org>
+ Copyright (c) 1994, 1999, 2007-2016 John E. Davis <jed@jedsoft.org>
  Copyright (c) 2002-2006 Thomas Schultz <tststs@gmx.de>
 
  This program is free software; you can redistribute it and/or modify it
@@ -16,7 +16,7 @@
 
  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
- 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef _SLRN_UTIL_H
 #define _SLRN_UTIL_H
@@ -65,7 +65,7 @@ extern char *slrn_fix_regexp (char *);
 extern void slrn_va_stderr_strcat (const char *, va_list);
 extern void slrn_stderr_strcat (const char *, ...);
 
-/* These declarations are here although the functions are not really defined 
+/* These declarations are here although the functions are not really defined
  * in util.c.
  */
 char *slrn_make_from_header (void);
